@@ -18,6 +18,7 @@ from .fft import *
 from .linear import *
 from .nonlinear import *
 from .operators_mpi import *
+from .proxy import *
 from . import iterative
 from .iterative import pcg
 from .rules import rule_manager
@@ -35,4 +36,8 @@ __all__ = [f for f in dir() if f[0] != '_' and not isinstance(eval(f),
 del f  #XXX not necessary with Python3
 del types
 
-__version__ = '0.11.1'
+I = IdentityOperator()
+O = ZeroOperator()
+X = Variable('X')
+
+__version__ = '0.12.3'
